#Collocations
#Context: neutral vs predictable
#Adjective: T1 (black vs bitter)- strong collocation vs weak collocation
#There are two different files: "Noun_T2_new.csv" where the interest area is the target word (coffee) and
#"Whole phrase_new.csv" where the interest area is the whole phrase (black coffee vs bitter coffee)
#26/01/2021
#Ascen Pagan

getwd()
setwd("~/Dropbox/Postdoc/Research Projects/Project students_Leicester/Lorna/new analysis")

library(MASS)
library(languageR)
library(lattice)
library (plotrix)
library(Matrix)
library(lme4)
library(carData)
library(effects)
library(stats)


# Load in the datafile & check it
datafile = read.csv(file.choose(), sep = ",")
head(datafile)
str(datafile)

# Making sure all variables are correct class
datafile$RECORDING_SESSION_LABEL = as.factor(datafile$RECORDING_SESSION_LABEL)
datafile$reading_condition = as.factor(datafile$reading_condition)
datafile$context=as.factor(datafile$context)
datafile$type_coll =as.factor(datafile$type_coll)
datafile$sentence_number = as.factor(datafile$sentence_number)
datafile$set = as.factor(datafile$set)
datafile$IA_FIRST_FIXATION_DURATION = as.integer(datafile$IA_FIRST_FIXATION_DURATION)
datafile$IA_FIRST_RUN_DWELL_TIME = as.integer(datafile$IA_FIRST_RUN_DWELL_TIME)
datafile$IA_DWELL_TIME = as.integer(datafile$IA_DWELL_TIME)
datafile$IA_REGRESSION_IN = as.integer(datafile$IA_REGRESSION_IN)
datafile$IA_REGRESSION_IN_COUNT = as.integer(datafile$IA_REGRESSION_IN_COUNT)
datafile$IA_REGRESSION_OUT = as.integer(datafile$IA_REGRESSION_OUT)
datafile$IA_REGRESSION_OUT_COUNT = as.integer(datafile$IA_REGRESSION_OUT_COUNT)
datafile$IA_REGRESSION_OUT_FULL = as.integer(datafile$IA_REGRESSION_OUT_FULL)
datafile$IA_REGRESSION_OUT_FULL_COUNT = as.integer(datafile$IA_REGRESSION_OUT_FULL_COUNT)
datafile$IA_REGRESSION_PATH_DURATION = as.integer(datafile$IA_REGRESSION_PATH_DURATION)
datafile$IA_SELECTIVE_REGRESSION_PATH_DURATION = as.integer(datafile$IA_SELECTIVE_REGRESSION_PATH_DURATION)
datafile$IA_SPILLOVER = as.integer(datafile$IA_SPILLOVER)


head(datafile)
str(datafile)
colnames(datafile)

#Eye movement measures

col.subject = 1      # specify which column your participant number is in
col.condition =  125  #specify which column contains your condition number, 
col.depvar =  8# specify which column your dependent variable is in , FFD
col.stim = 129    #stimulus
crit = 2.5             # setting the criterium value you want, usually 3 or 2.5 standard deviations

############## Here starts the part that's the same for all experiments

datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$depvar = datafile[,col.depvar]
datafile$stim = datafile[,col.stim]


#matrix0 will be all cases where there is something other than an NA
#Use this for total time, etc. - if there is a value of NA in FFD then
#there is a value of NA in all DV columns (except spillover - sort that
#out separately).  NA is marking missing values. 

matrix1 = datafile[!is.na(datafile$depvar),]
is.na(matrix1$depvar)

#Select dependent variable
#Let's remove the first fix that are actually not during first pass (GD & FFD)
matrix2 = matrix1[matrix1$IA_FIRST_FIX_PROGRESSIVE == 1,]

#SFD
matrix2 = matrix1[matrix1$IA_FIRST_FIX_PROGRESSIVE == 1 & matrix1$IA_FIXATION_COUNT ==1,]

#TT and go past time
matrix2 = matrix1[matrix1$depvar>0,]

#Regressions In and Out
matrix2 = matrix1

#####Get rid of the outliers 

nrcolumns = ncol(matrix2) #this is for cleaning up

#let's first have a look

head(matrix2)

# make a matrix with the means per subject and per condition for the dependent variable
mean.matrix2 = tapply(matrix2$depvar, list(matrix2$pp, matrix2$condition),mean)
mean.matrix2

#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix2 = tapply(matrix2$depvar,list(matrix2$pp, matrix2$condition), sd)
sd.matrix2
summary(matrix2$depvar)

#add this data to the actual dataframe
for(i in 1:nrow(matrix2)){matrix2$mean.sc[i] = mean.matrix2[matrix2$pp[i],matrix2$condition[i]]}
for(i in 1:nrow(matrix2)){matrix2$sd.sc[i] = sd.matrix2[matrix2$pp[i],matrix2$condition[i]]}

unique(matrix2$mean.sc)

#calculate z-scores
for(i in 1:nrow(matrix2)) {matrix2$zscore[i] = (matrix2$depvar[i] - matrix2$mean.sc[i])/matrix2$sd.sc[i]}

# assign a zero value to cells with only 1 observation
#matrix2$zscore[is.na(matrix1$zscore)] = 0 --- I've already removed NA values
#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)

result = matrix2[abs(matrix2$zscore) < crit,]

#you might want to clean up this data file by removing the added columns
result = result[,1:nrcolumns]

FFD_Region2 = result    # insert the name from the datafile coming from the cleanup on the right
datafile = FFD_Region2

#Let's see the data
densityplot(datafile$depvar)
#densityplot(datafile$ldepvar)


# Do we need to transform?
qqnorm(datafile$depvar)
qqnorm(log(datafile$depvar))

# yep, we are doing log transform
#datafile$ldepvar = log(datafile$depvar)

# How does it look at an individual level
#qqmath(~ldepvar|pp, data = datafile)


# Descriptives <<<<<
tapply(datafile$depvar, list(datafile$context,datafile$type_coll), mean, na.rm = T)
tapply(datafile$depvar, list(datafile$context,datafile$type_coll), sd, na.rm = T)
tapply(datafile$depvar, list(datafile$context,datafile$type_coll), std.error, na.rm = T)

  ############ OUTPUT

nrow(datafile)


###################

#Analysis

unique(datafile$context)
unique(datafile$type_coll)

datafile$context = factor(datafile$context)
datafile$type_coll = factor(datafile$type_coll)

contrasts(datafile$context)<-contr.sdif(2)
contrasts(datafile$type_coll)<-contr.sdif(2)

#Glmer models

depvar.lmer1 = glmer(depvar ~ context*type_coll + (1 +type_coll|pp) + (1+type_coll|stim), control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)), data = datafile, family= "Gamma"(link = "identity"))
summary(depvar.lmer1)

depvar.lmer1 = glmer(depvar ~ context*type_coll + (1|pp)+ (1|stim), control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)), data = datafile, family= binomial)
summary(depvar.lmer1)

# Lmer models

depvar.lmer2 = lmer(depvar ~ context*type_coll + (1 +type_coll|pp) + (1 +type_coll|stim), control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)), data = datafile)
summary(depvar.lmer2)

depvar.lmer2 = lmer(depvar ~ context*type_coll + (1|pp) + (1|stim), control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)), data = datafile)
summary(depvar.lmer2)

###########################BayesFactor####################

library(BayesFactor)


###set parameters for analysis 
iterations <- 100000  
rscaleFixed <- 0.5    # scaling factor for g-priors for fixed effects - this is the same as the default (cauchy)
whichRandom <- c("pp", "stim")  # specify random effects

colnames(datafile)

#This package doesn't work with glmer, so we're basing this on the lmer models (the results are very similar for both sets of models)

#We are going to use the pattern of significance from the lmer output to determine the model structure here, so it differs across measures

#Get the BF for a model with and without an interaction

#This package doesn't like NA, so if you have NA values, you can remove them before continuing
datafile = datafile[!is.na(datafile$depvar),]

bfFull <- lmBF (depvar ~ context + type_coll + context:type_coll + pp + stim, whichRandom = whichRandom, rscaleFixed = rscaleFixed, iterations = iterations, datafile)
bfFull


#This is a model with no fixed effects, in case we want to check are fixed effects vs baseline

bfBaseline <- lmBF (depvar ~ pp + stim, whichRandom = whichRandom, rscaleFixed = rscaleFixed, iterations = iterations,  datafile)


bfMain <- lmBF (depvar ~context + type_coll + pp + stim, whichRandom = whichRandom, rscaleFixed = rscaleFixed, iterations = iterations, datafile)
bfMain

bfoneMain <- lmBF (depvar ~ context + pp + stim, whichRandom = whichRandom, rscaleFixed = rscaleFixed, iterations = iterations, datafile)

bfoneMaininteraction <- lmBF (depvar ~ context + context:type_coll + pp + stim, whichRandom = whichRandom, rscaleFixed = rscaleFixed, iterations = iterations, datafile)

#Now compare to get the BF

bfoneMaininteraction/bfoneMain

bfFull/bfMain



##################sensitivity analsyses- let's verify that our choice of prior doesn't affect interpretation ###############################

priorRange<- c(0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8)

B<- NULL

for(i in 1:length(priorRange)){
  bfFull= lmBF (depvar ~ context + type_coll + context:type_coll + pp + stim,
                whichRandom = whichRandom, rscaleFixed = priorRange[i],
                iterations = iterations, datafile)
  
  bfMain= lmBF (depvar ~ context + type_coll + + pp + stim, whichRandom = whichRandom,
                rscaleFixed = priorRange[i], iterations = iterations, datafile)
  
  # extract bf
  B[i]<- extractBF(bfFull/bfMain)$bf
}


db<- data.frame(priorRange, B)


# let's check the values
db

# They all look similar

################### Clean-up
rm(list = ls(all = TRUE))


################### Clean-up
rm(list = ls(all = TRUE))


